unit flocateguimain; 

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, IBConnection, sqldb, db, FileUtil, Forms, Controls,
  Graphics, Dialogs, StdCtrls, Menus, ComCtrls, DBGrids, EditBtn, search, flocatedb;

type

  { TMainForm }

  TMainForm = class(TForm)
    DatasourceResult: TDatasource;
    DatasourceCatalogs: TDatasource;
    RootDirectoryControl: TDirectoryEdit;
    NewCatalogButton: TButton;
    DBGrid1: TDBGrid;
    CatalogSelection: TDBGrid;
    IBConnection1: TIBConnection;
    MainMenu1: TMainMenu;
    CatalogDefaultSelect: TRadioButton;
    CatalogSpecificSelect: TRadioButton;
    ScanButton: TButton;
    CommandGroup: TGroupBox;
    ResultButton: TButton;
    SQLQueryResults: TSQLQuery;
    SQLTransaction1: TSQLTransaction;
    procedure CatalogDefaultSelectChange(Sender: TObject);
    procedure CatalogSpecificSelectChange(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ScanButtonClick(Sender: TObject);
    procedure UpdateData;
  private
    { private declarations }
    FFLocateDB: TFlocateDB;
  public
    { public declarations }
  end; 

var
  MainForm: TMainForm;

implementation
uses flocateshared {config};

{$R *.lfm}

{ TMainForm }

procedure TMainForm.UpdateData;
begin
  if CatalogDefaultSelect.Checked = true then
  begin
    CatalogSelection.Enabled:=false;
    CatalogSelection.Visible:=false;
    NewCatalogButton.Enabled:=false;
  end
  else
  begin
    DatasourceCatalogs.Enabled:=true;
    CatalogSelection.Enabled:=true;
    CatalogSelection.Visible:=true;
    NewCatalogButton.Enabled:=true;
  end;
end;

procedure TMainForm.CatalogDefaultSelectChange(Sender: TObject);
begin
  UpdateData;
end;

procedure TMainForm.CatalogSpecificSelectChange(Sender: TObject);
begin
  UpdateData;
end;

procedure TMainForm.FormCreate(Sender: TObject);
var
  Config: Tflocateshared;
  DBParams: TStringList;
begin
  // Set up database
  Config := Tflocateshared.Create;
  DBParams := TStringList.Create;
  Try
    if Config.UseEmbedded = false then
    begin
      DBParams.Add('port=' + IntToStr(Config.Port));
      IBConnection1.HostName := Config.Host;
    end
    else
    begin
      IBConnection1.HostName := '';
    end;
    IBConnection1.Params := DBParams;
    IBConnection1.DatabaseName := Config.Database;
    IBConnection1.Username := Config.User;
    IBConnection1.Password := Config.Password;
    IBConnection1.Charset := 'UTF8';
  finally
    Config.free;
  end;
  UpdateData;
  FFLocateDB:=TFlocateDB.Create;
  DatasourceCatalogs.DataSet:=FFlocateDB.CatalogScans;
end;

procedure TMainForm.FormDestroy(Sender: TObject);
begin
  FFLocateDB.Free;
end;

procedure TMainForm.ScanButtonClick(Sender: TObject);
var
  Search: TFileSearch;
begin
  if RootDirectoryControl.Text='' then
  begin
    ShowMessage('Please select a starting directory for the search first.');
    exit;
  end;

  Search := TFileSearch.Create;
  try
    Screen.Cursor := crHourglass;
    try
      Search.RootDirectory := RootDirectoryControl.Text;
      Search.Directory := false; //mmm. is this necessary?
      Search.SearchSubdirectories := true;
      Search.Hidden := true;
      Search.ReadOnly := true;
      Search.System := true;
      Search.Search;
      Search.SaveToDatabase('Auto-generated '+DateTimeToStr(Now),'Scan of '+Search.RootDirectory);
    except
      on E: Exception do
      begin
        ShowMessage('Flocate: Error searching for files. Technical details: '+
          E.ClassName+'/'+E.Message);
      end;
    end;
    UpdateData;
  finally
    Screen.Cursor := crDefault;
    Search.Free;
  end;
end;

end.

